import es
import gamethread
import keymenulib
import langlib
import popuplib

errors = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/admin/errors.ini")
messages = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/admin/messages.ini")

# ******************** Load ********************
def load():
	create_popup()

	es.keygroupload("soccer_mod_admins", "soccer_mod")
	es.keygroupload("soccer_mod_maps", "soccer_mod")

	es.keygroupcreate("sm_keygroup_set")

	es.load("soccer_mod_2010/manager")

# ******************** Create popup ********************
def create_popup():
	text = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/admin/popup_admin.ini")

	popup = popuplib.create("sm_popup_admin")

	temp_string = "SOCCER MOD %s" % (text("title"))
	popup.addline(temp_string)

	popup.addline(" ")

	number = 0

	enabled = es.ServerVar("sm_module_match_on")
	if enabled == 1:
		number += 1
		temp_string = "->%s. %s" % (number, text("match"))
		popup.addline(temp_string)
		popup.select(number, match)

	enabled = es.ServerVar("sm_module_cap_on")
	if enabled == 1:
		number += 1
		temp_string = "->%s. %s" % (number, text("cap"))
		popup.addline(temp_string)
		popup.select(number, cap)

	enabled = es.ServerVar("sm_module_referee_on")
	if enabled == 1:
		number += 1
		temp_string = "->%s. %s" % (number, text("referee"))
		popup.addline(temp_string)
		popup.select(number, referee)

	enabled = es.ServerVar("sm_module_training_on")
	if enabled == 1:
		number += 1
		temp_string = "->%s. %s" % (number, text("training"))
		popup.addline(temp_string)
		popup.select(number, training)

	number += 1
	temp_string = "->%s. %s" % (number, text("map"))
	popup.addline(temp_string)
	popup.select(number, select_change_map)

	number += 1
	temp_string = "->%s. %s" % (number, text("settings"))
	popup.addline(temp_string)
	popup.select(number, settings)

	number += 1
	temp_string = "->%s. %s" % (number, text("manager"))
	popup.addline(temp_string)
	popup.select(number, manager)

	popup.addline(" ")
	temp_string = "->0. %s" % (text("close"))
	popup.addline(temp_string)

	number += 1
	while number < 10:
		popup.submenu(number, "sm_popup_admin")
		number += 1

# ******************** Events ********************
def es_map_start(event_var):
	exists = es.exists("key", "soccer_mod_maps", event_var["mapname"])
	if exists == 1:
		es.set("soccer_mod_allowed", 1)
		es.server.queuecmd("phys_pushscale 900")
	else:
		es.set("soccer_mod_allowed", 0)
		es.server.queuecmd("phys_pushscale 1")

	delete_keygroup("sm_keygroup_set")
	es.keygroupcreate("sm_keygroup_set")

def player_disconnect(event_var):
	name = "sm_popup_%s" % (event_var["userid"])
	if popuplib.exists(name):
		popuplib.delete(name)

	name = "sm_keymenu_%s" % (event_var["userid"])
	if keymenulib.exists(name):
		keymenulib.delete(name)

# ******************** Admin command ********************
def cmd_admin():
	userid = es.getcmduserid()
	steamid = es.getplayersteamid(userid)

	exists = es.exists("key", "soccer_mod_admins", steamid)
	if exists == 1:
		popuplib.send("sm_popup_admin", userid)
	else:
		es.tell(userid, "#green", errors("admin"))

# ******************** Popup choices ********************
def match(userid, choice, popupid):
	admin_popup_check("match", userid)

def cap(userid, choice, popupid):
	admin_popup_check("cap", userid)

def referee(userid, choice, popupid):
	admin_popup_check("referee", userid)

def training(userid, choice, popupid):
	admin_popup_check("training", userid)

def select_change_map(userid, choice, popupid):
	name = "sm_keymenu_%s" % (userid)
	if keymenulib.exists(name):
		keymenulib.delete(name)

	keymenu = keymenulib.create(name, "target", change_map, "soccer_mod_maps", "#key", "#key", "Change the map")
	keymenu.backmenu("sm_popup_admin")
	keymenulib.send(name, userid)

def change_map(userid, choice, keymenuname):
	exists = es.exists("map", choice)
	if exists == 1:
		name = es.getplayername(userid)
		message = "%s has changed the map to %s." % (name, choice)
		es.msg("#green", message)
		gamethread.delayed(3, load_map, (choice))
	else:
		message = "Map %s does not exist on this server." % (choice)
		es.tell(userid, "#green", message)
		popuplib.send("sm_popup_admin", userid)

def settings(userid, choice, popupid):
	admin_popup_check("settings", userid)

def manager(userid, choice, popupid):
	steamid = es.getplayersteamid(userid)

	check = int(es.keygetvalue("soccer_mod_admins", steamid, "manager"))
	if check == 1:
		popuplib.send("sm_popup_admin_manager", userid)
	else:
		es.tell(userid, "#green", errors("manager"))
		popuplib.send("sm_popup_admin", userid)

# ******************** Functions ********************
def load_map(name):
	cmd = "changelevel %s" % (name)
	es.server.queuecmd(cmd)

def admin_popup_check(module, userid):
	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		steamid = es.getplayersteamid(userid)
		check = int(es.keygetvalue("soccer_mod_admins", steamid, module))
		if check == 1:
			line = "sm_popup_admin_%s" % (module)
			popuplib.send(line, userid)
		else:
			es.tell(userid, "#green", errors(module))
			popuplib.send("sm_popup_admin", userid)
	else:
		es.tell(userid, "#green", errors("allowed"))
		popuplib.send("sm_popup_admin", userid)

def delete_popup(name):
	if popuplib.exists(name):
		popuplib.delete(name)

def delete_keygroup(name):
	exists = es.exists("keygroup", name)
	if exists == 1:
		es.keygroupdelete(name)

# ******************** Unload ********************
def unload():
	delete_keygroup("soccer_mod_admins")
	delete_keygroup("soccer_mod_maps")
	delete_keygroup("sm_keygroup_set")

	delete_popup("sm_popup_admin")

	es.unload("soccer_mod_2010/manager")